/*********************************************
 * vim:sw=8:ts=8:si:et
 * This is the header file the sensirion temperature and
 * humidity sensor. 
 *
 * Based on ideas from the sensirion application note and modified
 * for atmega88/168. 
 * A major part of the code was optimized and as a result the compiled 
 * code size was reduced to 50%.
 *
 * Modifications by: Guido Socher 
 *
 * Note: the sensirion SHTxx sensor does _not_ use the industry standard
 * I2C. The sensirion protocol looks similar but the start/stop
 * sequence is different. You can not use the avr TWI module.
 *
 *********************************************/
//@{
#ifndef SENSIRION_PROTOCOL_H
#define SENSIRION_PROTOCOL_H

// note: hardware connection definitions are in sensirion_protocol.c at
// the beginning of the inensirion_protocol.c file. You need to change
// the coded there if you connect the sensor to other pins.
//
extern void s_connectionreset(void);
extern char s_softreset(void);
extern char s_measure(unsigned int *p_value, unsigned char mode);
extern int calc_sth11_temp(unsigned int t);
extern unsigned char rhcalc_int(unsigned int s);
extern unsigned char calc_sth11_humi(unsigned int h, int t);
extern int calc_dewpoint(unsigned char rh,int t);
extern int log10_approx(unsigned char x);

#endif /* SENSIRION_PROTOCOL_H */
//@}
